function  [siz, vdim, name, datatype] = data_readinfo(index);

% data_readinfo        - Reading for the jezzard dataset.
%
%	function  [siz, vdim, name, datatype] = data_readinfo(index);
%
%	Input:	index     Scan index
%
%	Output:	siz       Volume dimensions
%               vdim      Voxel dimension
%               name      Name of data set
%               datatype  Data type, that float/short/...
%
%       See also: data_readdata


    siz = [64 1 64];	            % x,y,z; Coronal: [64 1 64]
    vdim = [0.0025 0.005 0.0025]    % 2.5x2.5  millimeter 
    name = 'jezzard';               % Anything goes here.
    datatype = 'short';             % 16 bits per byte






